![logo](logo.png)

---

A collection of tools to analyze and visualize atmospheric aerosol data.

## Installation
```shell
pip install aerosol-functions
```

## Documentation
See [here](https://jlpl.github.io/aerosol-functions/)
